$! Parameters:
$!	P1	Build options
$!			MULTINET or NETLIB	- Select TCP stack support
$!			LINK-ONLY		- Bypass compilation stage
$!			VAXC			- Force use of VAXC
$!			GNUC			- Force use of GNUC
$!			DEBUG			- compile/link with debugger support
$!			OPTIMIZE		- Forces optimization if DEBUG not set
$!
$!	P2	List of modules to be compiled
$!			a,b,c,...		- Compile a,b,c,... only
$!			NULL			- Compile everything
$!
$! Author:
$!	Andy Harper, Kings College London
$!
$
$ OPEN/WRITE OUTFILE DATE.C
$ WRITE OUTFILE "char datestamp[]=""''F$TIME()'"";"
$ close outfile
$ purge /nolog DATE.C
$!
$!
$ CCLIENT_DIR = "[-.IMAP.ANSI.C-CLIENT]"
$ Includes    ="[],''CCLIENT_DIR'"
$
$ COPY/nolog OS_VMS.H OS.H;
$ COPY/nolog HELPTEXT_VMS.H HELPTEXT.H;
$ COPY/nolog HELPTEXT_VMS.C HELPTEXT.C;
$ COPY/nolog INIT_VMS.C INIT.C;
$ purge/nolog os.h
$ purge/nolog helptext.h
$ purge/nolog helptext.c
$ purge/nolog init.c
$
$
$! Set up for appropriate compiler
$ CC_PREF = ""
$ LINK_OPT = ""
$ sysdef = ""
$ netdef = ""
$ arpdef = ""
$
$! Find out which compilers we have
$ HAVEVAXC = f$search("sys$system:vaxc.exe") .nes. ""
$ HAVEDECC = f$search("sys$system:decc$compiler.exe") .nes. ""
$ HAVEGNUC = F$SEARCH("GNU_CC:[000000]GCC.EXE")       .NES. ""
$
$! ... and which one to use in preference (if any)
$ FORCEVAXC= f$locate("VAXC",P1) .lt. f$length(P1)
$ FORCEGNUC = f$locate("GNUC",P1) .lt. f$length(P1)
$ if .not. (HAVEDECC .or. HAVEVAXC .or. HAVEGNUC)
$   then
$     write sys$output "%VMSBUILD-E-NOCC, No supported C compiler detected"
$     exit
$ endif
$
$
$! Auto-select, in order of preference, the best compiler available
$ COMPILER = ""
$ if (HAVEGNUC) then $ COMPILER = "GNU C"
$ if (HAVEVAXC) then $ COMPILER = "VAX C"
$ if (HAVEDECC) then $ COMPILER = "DEC C"
$
$! Multiple compilers specified?
$ if (FORCEVAXC .and. FORCEGNUC)
$   then
$     write sys$output "%VMSBUILD-E-AMBIG, Multiple C compilers specified"
$     exit
$ endif
$
$! Has user requested GNU C?
$ if FORCEGNUC
$   then
$     if .not. HAVEGNUC
$       then
$         write sys$output "%VMSBUILD-E-NOGNUC, GNUC selected but not installed"
$         exit
$     endif
$     COMPILER = "GNU C"
$ endif
$
$! Has user requested VAX C
$ if (FORCEVAXC)
$   then
$     if .not. HAVEVAXC
$       then
$         write sys$output "%VMSBUILD-E-NOVAXC, VAXC selected but not installed"
$         exit
$     endif
$     COMPILER = "VAX C"
$ endif
$
$ IF (COMPILER .eqs. "GNU C")
$   THEN
$       if f$type(GCC) .nes. ""
$         then
$           CC = GCC		! Defined foreign
$         else
$           CC = "GCC"		! Defined via SET COMMAND
$       endif
$
$       LINK_OPT = ",[-]VMS_GCC_LINK/OPTION"
$ ENDIF
$
$ IF (COMPILER .eqs. "VAX C")
$   THEN
$       if (HAVEDECC) then $ CC_PREF = CC_PREF + "/VAXC"
$       
$       sysdef   = "SYS$LIBRARY"
$	netdef   = "SYS$LIBRARY"
$	LINK_OPT = ",[-]VMS_LINK/OPTION"
$ ENDIF
$
$ IF (COMPILER .eqs. "DEC C")
$   THEN
$       if (HAVEVAXC) then $ CC_PREF = CC_PREF + "/DECC"
$
$	CC_PREF = CC_PREF + "/STANDARD=VAXC"
$	LINK_OPT = ""
$ ENDIF
$
$! Deassign any prior logicals in case we previously run something
$ IF F$TRNLNM("SYS")     .NES. "" THEN $ DEASSIGN SYS
$ IF F$TRNLNM("NETINET") .NES. "" THEN $ DEASSIGN NETINET
$ IF F$TRNLNM("ARPA")    .NES. "" THEN $ DEASSIGN ARPA
$
$! Set up the defines based on the compiler requirements and the network requirements
$ if (sysdef .nes. "") then $ define /nolog sys     'sysdef'
$ if (netdef .nes. "") then $ define /nolog netinet 'netdef'
$ if (arpdef .nes. "") then $ define /nolog arpa    'arpdef'
$ 
$!
$! DETERMINE NETWORK SUPPORT
$!
$ HAVENETLIB = f$trnlnm("NETLIB_DIR","LNM$SYSTEM") .nes. ""
$ HAVEMULTINET = f$trnlnm("MULTINET","LNM$SYSTEM") .nes. ""
$ FORCENETLIB = f$locate("NETLIB",P1) .lt. f$length(P1)
$ FORCEMULTINET = f$locate("MULTINET",P1) .lt. f$length(P1)
$ if (FORCEMULTINET .and. FORCENETLIB)
$   then
$     write sys$output "%VMSBUILD-E-CONFLTCP, Conflicting TCP stacks specified"
$     exit
$ endif
$
$! Pick best stack available
$ NETSTACK = "NO"
$ if (HAVEMULTINET) then $ NETSTACK = "MULTINET"
$ if (HAVENETLIB)   then $ NETSTACK = "NETLIB"
$
$ if (FORCEMULTINET)
$   then
$     if .not. HAVEMULTINET
$       then
$         write sys$output "%VMSBUILD-E-NOTCP, MULTINET tcp not installed"
$         exit
$     endif
$     NETSTACK = "MULTINET"
$ endif
$
$ if (FORCENETLIB)
$   then
$     if .not. HAVENETLIB
$       then
$         write sys$output "%VMSBUILD-E-NOTCP, NETLIB tcp not installed"
$         exit
$     endif
$     NETSTACK = "NETLIB"
$ endif
$
$ if (NETSTACK .eqs. "NO")
$   then
$ endif
$
$! Set up parameters for the network stack
$ IF (NETSTACK .eqs. "MULTINET")
$ THEN
$     LINK_OPT = ",[-]VMS_MULTINET_LINK/OPTION" + LINK_OPT
$ ENDIF
$
$ IF (NETSTACK .eqs. "NETLIB")
$   THEN
$     LINK_OPT = ",[-]VMS_NETLIB_LINK/OPTION" + LINK_OPT
$ ENDIF
$!
$! Initialize for debugging (or not)
$ IF F$LOCATE("DEBUG",P1) .lt. f$length(p1)
$   THEN			! Build a debug version of PINE
$     CC_PREF = CC_PREF + "/DEBUG /NOOPTIMIZE"
$     LINK   = "LINK /DEBUG"
$   ELSE
$     IF F$LOCATE("OPTIMIZE",P1) .lt. f$length(P1)	! /OPT is not default!
$       THEN
$         CC_PREF = CC_PREF + "/OPTIMIZE"
$       ELSE
$         CC_PREF = CC_PREF + "/NOOPTIMIZE"
$     ENDIF
$     LINK   = "LINK"
$ ENDIF
$
$ if f$locate("LINK-ONLY",P1) .lt. f$length(P1) then $ goto LINK
$
$ CC_PREF = CC_PREF + "/DEFINE=(SIGUSR2=SIGKILL,DEBUG,SYSTYPE=""""""VMS"""""")
$ CC_PREF = CC_PREF + "/INCLUDE=(''includes')"
$! CC_PREF = CC_PREF + "/LIST/SHOW=ALL"
$
$!
$ write sys$output "%VMSBUILD-I-BUILD, Building PINE using ", COMPILER, " with ", NETSTACK, " TCP/IP support"
$ if (P2 .nes. "")
$   then
$ SET VER
$ CC'CC_PREF' 'P2'
$ SET NOVER
$   else
$ SET VER
$ CC'CC_PREF' OS_vms
$ CC'CC_PREF' addrbook
$ CC'CC_PREF' adrbklib
$ CC'CC_PREF' args
$ CC'CC_PREF' context
$ CC'CC_PREF' date
$ CC'CC_PREF' filter
$ CC'CC_PREF' folder
$ CC'CC_PREF' help
$ CC'CC_PREF' helptext
$ CC'CC_PREF' imap
$ CC'CC_PREF' init
$ CC'CC_PREF' mailcap
$ CC'CC_PREF' mailcmd
$ CC'CC_PREF' mailindx
$ CC'CC_PREF' mailpart
$ CC'CC_PREF' mailview
$ CC'CC_PREF' newmail
$ CC'CC_PREF' other
$ CC'CC_PREF' pine
$ CC'CC_PREF' print
$ CC'CC_PREF' reply
$ CC'CC_PREF' screen
$ CC'CC_PREF' send
$ CC'CC_PREF' signals
$ CC'CC_PREF' status
$ CC'CC_PREF' strings
$ CC'CC_PREF' tty_vms
$ SET NOVER
$ endif
$ LIBRARY/OBJECT/CREATE/INSERT PINE *.obj
$ PURGE/nolog PINE.OLB
$!
$LINK:
$ write sys$output "%VMSBUILD-I-LINK,  Linking PINE"
$ IF (COMPILER .EQS. "DEC C")
$ THEN
$	LINK PINE,PINE/LIBR,'CCLIENT_DIR'C-CLIENT/LIBR,[-.PICO]PICO/LIBR'LINK_OPT'
$ ELSE
$	LINK PINE, -
	ADDRBOOK,ADRBKLIB,ARGS,CONTEXT,DATE,FILTER,FOLDER, -
	help,HELPTEXT,IMAP,INIT,MAILCAP,MAILCMD,MAILINDX,MAILVIEW,mailpart,NEWMAIL, -
	status,OTHER,PRINT,REPLY,SCREEN,SEND,SIGNALS,STRINGS,TTY_VMS,os_VMS, -
	[-.pico]pico/libr,'CCLIENT_DIR'IMAP2,MAIL,MISC,NNTP,NNTPCVMS,NEWSRC, -
	OS_VMS,RFC822,SMTP,SM_VMS,VMS_MAIL,TCP_VMS,SYS$INPUT:/OPTION'LINK_OPT'
$ ENDIF
$ PURGE/NOLOG *.OBJ
$ PURGE/NOLOG *.EXE
